===================
Plotting with bokeh
===================

It is possible to implement graphs using the bokeh library and embed
them in reports:

.. report:: Trackers.ArrayDataExample
      :render: bk-line-plot
      :as-lines:

      Line plots with Bokeh
